==> plantuml_1.2017.15.orig.tar.gz: plantuml-1.2017.15/src/h/ST_Agiddisc_s.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of Smetana.
 * Smetana is a partial translation of Graphviz/Dot sources from C to Java.
 *
 * (C) Copyright 2009-2017, Arnaud Roques
 *
 * This translation is distributed under the same Licence as the original C program:
 * 
 *************************************************************************
 * Copyright (c) 2011 AT&T Intellectual Property 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors: See CVS logs. Details at http://www.graphviz.org/
 *************************************************************************
 *
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS ECLIPSE PUBLIC
 * LICENSE ("AGREEMENT"). [Eclipse Public License - v 1.0]
 * 
 * ANY USE, REPRODUCTION OR DISTRIBUTION OF THE PROGRAM CONSTITUTES
 * RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT.
 * 
 * You may obtain a copy of the License at
 * 
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package h;

import smetana.core.CFunction;
import smetana.core.UnsupportedStarStruct;
import smetana.core.UnsupportedStruct;
import smetana.core.__ptr__;
import smetana.core.amiga.StarStruct;


public class ST_Agiddisc_s extends UnsupportedStruct {

	public CFunction open;
	public CFunction map;
	public CFunction alloc;
	public CFunction free;
	public CFunction print;
	public CFunction close;
	public CFunction idregister;

	@Override
	public StarStruct amp() {
		return new UnsupportedStarStruct() {
			@Override
			public Object call(String fieldName, Object... args) {
				if (fieldName.equals("open")) {
					return open.exe(args);
				}
				if (fieldName.equals("map")) {
					return map.exe(args);
				}
				if (fieldName.equals("idregister")) {
					return idregister.exe(args);
				}
				if (fieldName.equals("print")) {
					return print.exe(args);
				}
				return super.call(fieldName, args);
			}

			@Override
			public __ptr__ getPtr(String fieldName) {
				if (fieldName.equals("print")) {
					return print;
				}
				return super.getPtr(fieldName);
			}

		};
	}

	// public static List<String> DEFINITION = Arrays.asList(
	// "struct Agiddisc_s",
	// "{",
	// "void *(*open) (Agraph_t * g, Agdisc_t*)",
	// "long (*map) (void *state, int objtype, char *str, unsigned long *id,    int createflag)",
	// "long (*alloc) (void *state, int objtype, unsigned long id)",
	// "void (*free) (void *state, int objtype, unsigned long id)",
	// "char *(*print) (void *state, int objtype, unsigned long id)",
	// "void (*close) (void *state)",
	// "void (*idregister) (void *state, int objtype, void *obj)",
	// "}");
}

// struct Agiddisc_s { /* object ID allocator */
// void *(*open) (Agraph_t * g, Agdisc_t*); /* associated with a graph */
// long (*map) (void *state, int objtype, char *str, unsigned long *id,
// int createflag);
// long (*alloc) (void *state, int objtype, unsigned long id);
// void (*free) (void *state, int objtype, unsigned long id);
// char *(*print) (void *state, int objtype, unsigned long id);
// void (*close) (void *state);
// void (*idregister) (void *state, int objtype, void *obj);
// };

==> plantuml_1.2018.9.orig.tar.gz: plantuml-1.2018.9/src/h/ST_Agiddisc_s.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of Smetana.
 * Smetana is a partial translation of Graphviz/Dot sources from C to Java.
 *
 * (C) Copyright 2009-2017, Arnaud Roques
 *
 * This translation is distributed under the same Licence as the original C program:
 * 
 *************************************************************************
 * Copyright (c) 2011 AT&T Intellectual Property 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors: See CVS logs. Details at http://www.graphviz.org/
 *************************************************************************
 *
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS ECLIPSE PUBLIC
 * LICENSE ("AGREEMENT"). [Eclipse Public License - v 1.0]
 * 
 * ANY USE, REPRODUCTION OR DISTRIBUTION OF THE PROGRAM CONSTITUTES
 * RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT.
 * 
 * You may obtain a copy of the License at
 * 
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package h;

import smetana.core.CFunction;
import smetana.core.UnsupportedStarStruct;
import smetana.core.UnsupportedStruct;
import smetana.core.__ptr__;
import smetana.core.amiga.StarStruct;

public class ST_Agiddisc_s extends UnsupportedStruct {

	public CFunction open;
	public CFunction map;
	public CFunction alloc;
	public CFunction free;
	public CFunction print;
	public CFunction close;
	public CFunction idregister;

	@Override
	public StarStruct amp() {
		return new Amp();
	}

	public class Amp extends UnsupportedStarStruct {
		@Override
		public Object call(String fieldName, Object... args) {
			if (fieldName.equals("open")) {
				return open.exe(args);
			}
			if (fieldName.equals("map")) {
				return map.exe(args);
			}
			if (fieldName.equals("idregister")) {
				return idregister.exe(args);
			}
			if (fieldName.equals("print")) {
				return print.exe(args);
			}
			return super.call(fieldName, args);
		}

		@Override
		public __ptr__ getPtr(String fieldName) {
			if (fieldName.equals("print")) {
				return print;
			}
			return super.getPtr(fieldName);
		}
	}

	// public static List<String> DEFINITION = Arrays.asList(
	// "struct Agiddisc_s",
	// "{",
	// "void *(*open) (Agraph_t * g, Agdisc_t*)",
	// "long (*map) (void *state, int objtype, char *str, unsigned long *id,    int createflag)",
	// "long (*alloc) (void *state, int objtype, unsigned long id)",
	// "void (*free) (void *state, int objtype, unsigned long id)",
	// "char *(*print) (void *state, int objtype, unsigned long id)",
	// "void (*close) (void *state)",
	// "void (*idregister) (void *state, int objtype, void *obj)",
	// "}");
}

// struct Agiddisc_s { /* object ID allocator */
// void *(*open) (Agraph_t * g, Agdisc_t*); /* associated with a graph */
// long (*map) (void *state, int objtype, char *str, unsigned long *id,
// int createflag);
// long (*alloc) (void *state, int objtype, unsigned long id);
// void (*free) (void *state, int objtype, unsigned long id);
// char *(*print) (void *state, int objtype, unsigned long id);
// void (*close) (void *state);
// void (*idregister) (void *state, int objtype, void *obj);
// };
